#!/usr/bin/env python

import os
import shutil
import numpy as np
import argparse
from astropy.io import fits


def crback(infile, maskfile, reffile, coordtable):
    data_ov = fits.getdata(reffile)

    orgfile = infile[:len(infile)-5]+'_org.fits'
    if os.path.exists(orgfile):
        print(orgfile + ' exists. '+
              'No need to backup the original file.')
    else:
        print('Copying ' + infile +' to ' + orgfile)
        shutil.copy(infile, orgfile)

    orgmaskfile = maskfile[:len(maskfile)-5]+'_org.fits'
    if os.path.exists(orgmaskfile):
        print(orgmaskfile + ' exists. ' + 
              'No need to backup the original file.')
    else:
        print('Copying ' + maskfile + ' to ' + orgmaskfile)
        shutil.copy(maskfile, orgmaskfile)
    
    hdl_cr = fits.open(infile, mode='update')
    data_cr = hdl_cr[0].data
    
    hdl_mask = fits.open(maskfile, mode='update')
    data_mask = hdl_mask[0].data

    coords = np.loadtxt(coordtable, dtype='int')

    if coords.ndim == 1:
        coord_num = 1
    elif coords.ndim == 2:
        coord_num = coords.shape[0]
    else:
        print('Error in the coodinate list file')
        return

    print('Number of coordinates: '+str(coord_num))

    if coords.ndim == 1:
        print(coords[1]-1, coords[0]-1)
        data_cr[coords[1]-1, coords[0]-1] = data_ov[coords[1]-1, coords[0]-1]
        data_mask[coords[1]-1, coords[0]-1] = 0
    elif coords.ndim == 2:
        for i in range(coord_num):
            print(coords[i,1]-1, coords[i,0]-1)
            data_cr[coords[i,1]-1, coords[i,0]-1] = data_ov[coords[i,1]-1, coords[i,0]-1]
            data_mask[coords[i,1]-1, coords[i,0]-1] = 0

    hdl_cr.close()
    hdl_mask.close()

    return
        
if __name__ == '__main__':
    parser=argparse.ArgumentParser(
        description='This is the script for replacing the pixel'+
        ' value to the value before cosmicray removing.')
    parser.add_argument('infile', help='File to be corrected.')
    parser.add_argument('maskfile', help='Mask file for INFILE')
    parser.add_argument('reffile', help='Reference file')
    parser.add_argument('coordtable',
                        help='List file of pixel coordinates to be replaced.')
    args = parser.parse_args()

    crback(args.infile, args.maskfile, args.reffile, args.coordtable)
