#!/usr/bin/env python

import numpy as np
import matplotlib.pyplot as plt
import argparse
from astropy.io import fits


def key(event):
    global flg
    if event.key == 'q':
        plt.close()
    elif event.key == 'i':
        flg = 0
        plt.close()
    elif event.key == '1':
        f = open(image1+'_crresiduals.txt', mode='a')
        print('{} {:4} {:4}\n'.format(image1, x, int(event.xdata+0.5)))
        f.write('{:4} {:4}\n'.format(x, int(event.xdata+0.5)))
        f.close()
    elif event.key == '2':
        f = open(image2+'_crresiduals.txt', mode='a')
        print('{} {:4} {:4}\n'.format(image2, x, int(event.xdata+0.5)))
        f.write('{:4} {:4}\n'.format(x, int(event.xdata+0.5)))
        f.close()
    else:
        print('Press following keys.')
        print('\tq: next spectrum')
        print('\ti: interrupt')
        print('\t1: residual for '+ image1)
        print('\t2: residual for '+ image2)
    return

def crplot(yc, ylength=800):
    # yc (pixel)
    # ylength (pixels)
    global flg, x, y1
    data1_ov = fits.getdata(image1+'.ov.fits')
    data1_cr = fits.getdata(image1+'.cr.fits')
    data1_mask = fits.getdata(image1+'.mask.fits')
    
    data2_ov = fits.getdata(image2+'.ov.fits')
    data2_cr = fits.getdata(image2+'.cr.fits')
    data2_mask = fits.getdata(image2+'.mask.fits')

    y = np.arange(1,data1_ov.shape[0]+1)

    y1 = int(yc - ylength/2)
    y2 = int(yc + ylength/2)

    flg = 1
    
    while(flg):
        print('X = '+str(x))
        fig = plt.figure(figsize=(18,8))
        cid = fig.canvas.mpl_connect('key_press_event', key)
        plt.plot(y, data1_ov[:,x-1], label=image1+'.ov')
        plt.plot(y, data1_cr[:,x-1], label=image1+'.cr')
    
        plt.plot(y, data2_ov[:,x-1], label=image2+'.ov')
        plt.plot(y, data2_cr[:,x-1], label=image2+'.cr')

        plt.xlim(y1, y2)
        ymin = np.min([np.min(data1_cr[y1:y2,x-1]),
                       np.min(data2_cr[y1:y2,x-1])])
        ymax = np.max([np.max(data1_cr[y1:y2,x-1]),
                       np.max(data2_cr[y1:y2,x-1])])
        ymargin = (ymax - ymin)*0.05
        plt.ylim(ymin - ymargin, ymax + ymargin)
        plt.subplots_adjust(left=0.05, right=0.98, bottom=0.1, top=0.9)
        plt.title('X='+str(x)+', Y center='+str(yc)+' in DS9')
        plt.xlabel('Y in DS9')
        plt.legend()
        plt.show()
        x=x+1

    return
    
if __name__ == '__main__':
    parser=argparse.ArgumentParser(description='This is the '+\
            'script for checking cosmic ray removing.')
    parser.add_argument('frame1', help='Frame ID 1')
    parser.add_argument('frame2', help='Frame ID 2')
    parser.add_argument('x', help='X coordinate to be plotted.', type=int)
    parser.add_argument('yc', help='Center Y coordinate to be plotted.', type=int)
    parser.add_argument('-dy', help='Y length to be plotted.', type=int)
    args = parser.parse_args()
    
    global x, image1, image2
    image1 = args.frame1
    image2 = args.frame2
    x = args.x
    crplot(args.yc, ylength=args.dy)
    
