#!/usr/bin/env python

import numpy as np
import matplotlib.pyplot as plt
import argparse
from astropy.io import fits


def implot(files, coos, w, flgx=False, flgy=False):
    files2 = files.split(',')

    if coos is None:
        data = fits.getdata(files2[0])
        x = int(data.shape[1]/2)
        y = int(data.shape[0]/2)
    else:
        x,y = [int(i) for i in coos.split(',')]

    for file in files2:
        data = fits.getdata(file)
        if flgx is False and flgy is False:
            if w is None:
                plt.plot(data[:,int(data.shape[1]/2)], label=file)
            else:
                xx = np.arange(y-w, y+w)
                plt.plot(xx, data[y-1-w:y-1+w,int(data.shape[1]/2)], label=file)    
            plt.title('X={} in DS9'.format(int(data.shape[1]/2)+1))
            plt.xlabel('Y (pix) in DS9')
        elif flgy:
            if w is None:
                plt.plot(data[:,x-1], label=file)
            else:
                xx = np.arange(y-w, y+w)
                plt.plot(xx, data[y-1-w:y-1+w,x-1], label=file)
            plt.title('X={} in DS9'.format(x))
            plt.xlabel('Y (pix)')
        elif flgx:
            if w is None:
                plt.plot(data[y,:], label=file)
            else:
                xx = np.arange(x1-w, x+w)
                plt.plot(xx, data[y,x-1-w:x-1+w], label=file)
            plt.title('Y={} in DS9'.format(y))
            plt.xlabel('X (pix)')

    plt.grid()
    plt.legend()
    plt.show()
        
    return


if __name__ == '__main__':
    parser=argparse.ArgumentParser(description='This is the script for '
                                   + 'plotting lines and columns of images.')
    parser.add_argument('files', help='Input FITS files (comma separated)')
    parser.add_argument('-c', help='Center coordinate (comma separated).',
                        default=None)
    parser.add_argument('-w', help='Center coordinate (comma separated).',
                        type=int, default=None)
    parser.add_argument('-flgx', help='Plot along X axis.',
                        action='store_true')
    parser.add_argument('-flgy', help='Plot along Y axis.',
                        action='store_true')
    args = parser.parse_args()
    
    implot(args.files, coos=args.c, w=args.w, flgx=args.flgx, flgy=args.flgy)
    
